slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEP

Abstract SLEPc object that manages all the polynomial eigenvalue problem solvers.

### Synopsis

    typedef struct _p_PEP* PEP;

### See Also

PEPCreate()

### Level

beginner

### Location

include/slepcpep.h

### Examples

src/pep/tutorials/ex16f90.F90.html
src/pep/tutorials/ex38.c.html
src/pep/tutorials/ex40.c.html
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages